@@ -1,7 +1,6 @@
 # -*- coding: utf8 -*-
 from .handler import Handler, EventType
 from .event import Event
-from .expect import Expect
 from .subject import Subject
 
-__all__ = ['Handler', 'EventType', 'Event', 'Expect', 'Subject']
+__all__ = ['Handler', 'EventType', 'Event', 'Subject']
